@@ -1,8 +1,6 @@
 
 context("stepDetection")
 
-library(stepR)
-
 testIncremental <- function(fit, thresholdIncremental) {
   leftEnd <- fit$leftEnd
   rightEnd <- fit$rightEnd
@@ -67,67 +65,67 @@ testdecision <- function(i, j, leftEnd, value, threshold) {
 
 context("postfilter")
 test_that("object is identical if no action has to be done", {
-  test <- stepblock(value = c(0, 1), leftEnd = c(1, 101), rightEnd = c(100, 200), x0 = NA)
-  compare <- stepblock(value = c(0, 1), leftEnd = c(1, 101), rightEnd = c(100, 200), x0 = NA)
+  test <- stepR::stepblock(value = c(0, 1), leftEnd = c(1, 101), rightEnd = c(100, 200), x0 = NA)
+  compare <- stepR::stepblock(value = c(0, 1), leftEnd = c(1, 101), rightEnd = c(100, 200), x0 = NA)
   expect_identical(testIncremental(test, thresholdIncremental = 8L), compare)
 })
 
 test_that("single incremental change is removed", {
-  test <- stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 101, 106),
-                    rightEnd = c(100, 105, 200), x0 = NA)
-  compare <- stepblock(value = c(0, 1), leftEnd = c(1, 101), rightEnd = c(100, 200), x0 = NA)
+  test <- stepR::stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 101, 106),
+                           rightEnd = c(100, 105, 200), x0 = NA)
+  compare <- stepR::stepblock(value = c(0, 1), leftEnd = c(1, 101), rightEnd = c(100, 200), x0 = NA)
   expect_identical(testIncremental(test, thresholdIncremental = 8L), compare)
 })
 
 test_that("two incremental changes are removed", {
-  test <- stepblock(value = c(0, 0.5, 0.7, 1), leftEnd = c(1, 101, 104, 106),
-                    rightEnd = c(100, 103, 105, 200), x0 = NA)
-  compare <- stepblock(value = c(0, 1), leftEnd = c(1, 101), rightEnd = c(100, 200), x0 = NA)
+  test <- stepR::stepblock(value = c(0, 0.5, 0.7, 1), leftEnd = c(1, 101, 104, 106),
+                           rightEnd = c(100, 103, 105, 200), x0 = NA)
+  compare <- stepR::stepblock(value = c(0, 1), leftEnd = c(1, 101), rightEnd = c(100, 200), x0 = NA)
   expect_identical(testIncremental(test, thresholdIncremental = 8L), compare)
 })
 
 test_that("distance is taken correctly into account", {
-  test <- stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 101, 109),
-                    rightEnd = c(100, 108, 200), x0 = NA)
-  compare <- stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 101, 109),
-                       rightEnd = c(100, 108, 200), x0 = NA)
+  test <- stepR::stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 101, 109),
+                           rightEnd = c(100, 108, 200), x0 = NA)
+  compare <- stepR::stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 101, 109),
+                              rightEnd = c(100, 108, 200), x0 = NA)
   expect_identical(testIncremental(test, thresholdIncremental = 8L), compare)
   
-  test <- stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 101, 108),
-                    rightEnd = c(100, 107, 200), x0 = NA)
-  compare <- stepblock(value = c(0, 1), leftEnd = c(1, 101), rightEnd = c(100, 200), x0 = NA)
+  test <- stepR::stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 101, 108),
+                           rightEnd = c(100, 107, 200), x0 = NA)
+  compare <- stepR::stepblock(value = c(0, 1), leftEnd = c(1, 101), rightEnd = c(100, 200), x0 = NA)
   expect_identical(testIncremental(test, thresholdIncremental = 8L), compare)
 })
 
 test_that("different direction is taken into account", {
-  test <- stepblock(value = c(0, -0.5, 1), leftEnd = c(1, 101, 106),
-                    rightEnd = c(100, 105, 200), x0 = NA)
-  compare <- stepblock(value = c(0, -0.5, 1), leftEnd = c(1, 101, 106),
-                       rightEnd = c(100, 105, 200), x0 = NA)
+  test <- stepR::stepblock(value = c(0, -0.5, 1), leftEnd = c(1, 101, 106),
+                           rightEnd = c(100, 105, 200), x0 = NA)
+  compare <- stepR::stepblock(value = c(0, -0.5, 1), leftEnd = c(1, 101, 106),
+                              rightEnd = c(100, 105, 200), x0 = NA)
   expect_identical(testIncremental(test, thresholdIncremental = 8L), compare)
 })
 
 test_that("first segment is not removed", {
-  test <- stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 7, 106),
-                    rightEnd = c(7, 105, 200), x0 = NA)
-  compare <- stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 7, 106),
-                       rightEnd = c(7, 105, 200), x0 = NA)
+  test <- stepR::stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 7, 106),
+                           rightEnd = c(7, 105, 200), x0 = NA)
+  compare <- stepR::stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 7, 106),
+                              rightEnd = c(7, 105, 200), x0 = NA)
   expect_identical(testIncremental(test, thresholdIncremental = 8L), compare)
 })
 
 test_that("last segment is not removed", {
-  test <- stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 100, 116),
-                    rightEnd = c(100, 116, 117), x0 = NA)
-  compare <- stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 100, 116),
-                       rightEnd = c(100, 116, 117), x0 = NA)
+  test <- stepR::stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 100, 116),
+                           rightEnd = c(100, 116, 117), x0 = NA)
+  compare <- stepR::stepblock(value = c(0, 0.5, 1), leftEnd = c(1, 100, 116),
+                              rightEnd = c(100, 116, 117), x0 = NA)
   expect_identical(testIncremental(test, thresholdIncremental = 8L), compare)
 })
 
 test_that("incremental changes at a peak are removed", {
-  test <- stepblock(value = c(0, 0.5, 0.7, 1, 0.5, 0), leftEnd = c(1, 101, 104, 106, 108, 110),
-                    rightEnd = c(100, 103, 105, 107, 109, 200), x0 = NA)
-  compare <- stepblock(value = c(0, 1, 0), leftEnd = c(1, 101, 108),
-                       rightEnd = c(100, 107, 200), x0 = NA)
+  test <- stepR::stepblock(value = c(0, 0.5, 0.7, 1, 0.5, 0), leftEnd = c(1, 101, 104, 106, 108, 110),
+                           rightEnd = c(100, 103, 105, 107, 109, 200), x0 = NA)
+  compare <- stepR::stepblock(value = c(0, 1, 0), leftEnd = c(1, 101, 108),
+                              rightEnd = c(100, 107, 200), x0 = NA)
   expect_identical(testIncremental(test, thresholdIncremental = 8L), compare)
 })
 
@@ -146,11 +144,11 @@ test_that("it works if sd and q is given and that data and filter have to be giv
   testsd <- 1
   testq <- 1.44
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = 0,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
-                             covariances = testsd^2 * testfilter$acf)
-  compare <- stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 0)
-    
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
+                            covariances = testsd^2 * testfilter$acf)
+  compare <- stepR::stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 0)
+  
   expect_error(stepDetection())
   expect_error(stepDetection(data = testdata))
   expect_identical(stepDetection(data = testdata, filter = testfilter, sd = testsd, q = testq), 
@@ -164,10 +162,10 @@ test_that("output is tested and works", {
   testsd <- 1
   testq <- 1.44
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = 0,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
-                             covariances = testsd^2 * testfilter$acf)
-  compare <- stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 0)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
+                            covariances = testsd^2 * testfilter$acf)
+  compare <- stepR::stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 0)
   compare <- list(fit = testIncremental(compare, thresholdIncremental = 8L), stepfit = compare,
                   q = testq, filter = testfilter, sd = testsd)
   
@@ -193,10 +191,10 @@ test_that("more difficult scenarios work", {
   testsd <- 1
   testq <- 1
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = 0,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
-                             covariances = testsd^2 * testfilter$acf)
-  compare <- stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 0)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
+                            covariances = testsd^2 * testfilter$acf)
+  compare <- stepR::stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 0)
   compare <- list(fit = testIncremental(compare, thresholdIncremental = 8L), stepfit = compare,
                   q = testq, filter = testfilter, sd = testsd)
   
@@ -220,10 +218,10 @@ test_that("more difficult scenarios work", {
   testsd <- 1
   testq <- 1
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = 0,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
-                             covariances = testsd^2 * testfilter$acf)
-  compare <- stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 0)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
+                            covariances = testsd^2 * testfilter$acf)
+  compare <- stepR::stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 0)
   compare <- list(fit = testIncremental(compare, thresholdIncremental = 8L), stepfit = compare,
                   q = testq, filter = testfilter, sd = testsd)
   
@@ -247,10 +245,10 @@ test_that("more difficult scenarios work", {
   testsd <- 1
   testq <- 1
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = 0,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
-                             covariances = testsd^2 * testfilter$acf)
-  compare <- stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 0)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
+                            covariances = testsd^2 * testfilter$acf)
+  compare <- stepR::stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 0)
   compare <- list(fit = testIncremental(compare, thresholdIncremental = 8L), stepfit = compare,
                   q = testq, filter = testfilter, sd = testsd)
   
@@ -276,10 +274,10 @@ test_that("argument data works and is tested", {
   testsd <- 1
   testq <- 1
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = 0,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
-                             covariances = testsd^2 * testfilter$acf)
-  compare <- stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 0)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
+                            covariances = testsd^2 * testfilter$acf)
+  compare <- stepR::stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 0)
   
   expect_error(stepDetection(data = c(testdata, "s"), filter = testfilter, sd = testsd, q = testq))
   expect_error(stepDetection(data = c(testdata, Inf), filter = testfilter, sd = testsd, q = testq))
@@ -295,13 +293,13 @@ test_that("argument startTime works and is tested", {
   testsd <- 1
   testq <- 1
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = 0,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
-                             covariances = testsd^2 * testfilter$acf)
-  compare <- stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 0)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
+                            covariances = testsd^2 * testfilter$acf)
+  compare <- stepR::stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 0)
   
   expect_identical(stepDetection(data = testdata, startTime = 0, filter = testfilter, sd = testsd,
-                             q = testq), testIncremental(compare, thresholdIncremental = 8L))
+                                 q = testq), testIncremental(compare, thresholdIncremental = 8L))
   expect_error(stepDetection(data = testdata, startTime = "0", filter = testfilter, sd = testsd,
                              q = testq))
   expect_error(stepDetection(data = testdata, startTime = Inf, filter = testfilter, sd = testsd,
@@ -313,13 +311,13 @@ test_that("argument startTime works and is tested", {
   testdata <- c(rnorm(108, 0), rnorm(5, 10), rnorm(5, 20), rnorm(5, 30), rnorm(100, 40))
   testdata <- .convolve(testdata, testfilter)
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = -1,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
-                             covariances = testsd^2 * testfilter$acf)
-  compare <- stepblock(value = compare$value,
-                       leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]) - 1,
-                       rightEnd = compare$rightEnd - 1, x0 = -1)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
+                            covariances = testsd^2 * testfilter$acf)
+  compare <- stepR::stepblock(value = compare$value,
+                              leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]) - 1,
+                              rightEnd = compare$rightEnd - 1, x0 = -1)
   expect_identical(stepDetection(data = testdata, startTime = -1, filter = testfilter,
-                             sd = testsd, q = testq), testIncremental(compare, thresholdIncremental = 8L))
+                                 sd = testsd, q = testq), testIncremental(compare, thresholdIncremental = 8L))
 })
 
 test_that("argument filter works and is tested", {
@@ -330,14 +328,14 @@ test_that("argument filter works and is tested", {
   testsd <- 1
   testq <- 1
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = 0,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
-                             covariances = testsd^2 * testfilter$acf)
-  compare <- stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 0)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
+                            covariances = testsd^2 * testfilter$acf)
+  compare <- stepR::stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 0)
   
   expect_error(stepDetection(data = testdata, filter = list(test = 1), sd = testsd, q = testq))
   expect_identical(stepDetection(data = testdata, filter = testfilter, sd = testsd, q = testq),
-               testIncremental(compare, thresholdIncremental = 5L))
+                   testIncremental(compare, thresholdIncremental = 5L))
   
   testdata <- c(rnorm(108, 0), rnorm(5, 10), rnorm(5, 20), rnorm(5, 30), rnorm(100, 40))
   testfilter <- lowpassFilter(type = "bessel", param = list(pole = 4L, cutoff = 0.1), sr = 10, len = 8L,
@@ -346,11 +344,11 @@ test_that("argument filter works and is tested", {
   testsd <- 1
   testq <- 1
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = 0,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
-                             covariances = testsd^2 * testfilter$acf)
-  compare <- stepblock(value = compare$value,
-                       leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 0)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
+                            covariances = testsd^2 * testfilter$acf)
+  compare <- stepR::stepblock(value = compare$value,
+                              leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 0)
   
   expect_identical(stepDetection(data = testdata, filter = testfilter, sd = testsd, q = testq),
                    testIncremental(compare,
@@ -364,11 +362,11 @@ test_that("argument filter works and is tested", {
   testq <- 1
   testtime <- 1 + 1:215 / 1e4
   compare <- stepR::stepFit(y = testdata, x = testtime, x0 = 1,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
-                             covariances = testsd^2 * testfilter$acf)
-  compare <- stepblock(value = compare$value,
-                       leftEnd = c(1, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 1)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
+                            covariances = testsd^2 * testfilter$acf)
+  compare <- stepR::stepblock(value = compare$value,
+                              leftEnd = c(1, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 1)
   
   expect_identical(stepDetection(data = testdata, filter = testfilter, sd = testsd, q = testq, startTime = 1),
                    testIncremental(compare,
@@ -383,10 +381,10 @@ test_that("argument sd works and is tested", {
   testsd <- 0.5
   testq <- 1
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = 0,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
-                             covariances = testsd^2 * testfilter$acf)
-  compare <- stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 0)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
+                            covariances = testsd^2 * testfilter$acf)
+  compare <- stepR::stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 0)
   
   expect_identical(stepDetection(data = testdata, filter = testfilter, sd = testsd, q = testq),
                    testIncremental(compare, thresholdIncremental = 8L))
@@ -396,10 +394,10 @@ test_that("argument sd works and is tested", {
   testdata <- .convolve(testdata, testfilter)
   testsd <- 0.5
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = 0,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
-                             covariances = testsd^2 * testfilter$acf)
-  compare <- stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 0)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
+                            covariances = testsd^2 * testfilter$acf)
+  compare <- stepR::stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 0)
   
   expect_identical(stepDetection(data = testdata, filter = testfilter, sd = testsd, q = testq),
                    testIncremental(compare, thresholdIncremental = 8L))
@@ -408,7 +406,7 @@ test_that("argument sd works and is tested", {
   expect_error(stepDetection(data = testdata, filter = testfilter, sd = c(1, 0.5), q = testq))
   expect_error(stepDetection(data = testdata, filter = testfilter, sd = -1, q = testq))
   
-  estsd <- sdrobnorm(testdata, lag = 9)
+  estsd <- stepR::sdrobnorm(testdata, lag = 9)
   expect_identical(stepDetection(data = testdata, filter = testfilter, q = testq),
                    stepDetection(data = testdata, filter = testfilter, sd = estsd, q = testq))
 })
@@ -426,10 +424,10 @@ test_that("argument q works and is tested", {
   expect_error(stepDetection(data = testdata, filter = testfilter, q = c(1, 2)))
   
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = 0,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
-                             filter = testfilter)
-  compare <- stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 0)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = testq,
+                            filter = testfilter)
+  compare <- stepR::stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 0)
   
   expect_identical(stepDetection(data = testdata, filter = testfilter, q = testq),
                    testIncremental(compare, thresholdIncremental = 8L))
@@ -440,7 +438,7 @@ test_that("argument alpha works and is tested", {
   testfilter <- lowpassFilter(type = "bessel", param = list(pole = 4L, cutoff = 0.1), sr = 1, len = 8L,
                               shift = 0.5)
   testdata <- .convolve(testdata, testfilter)
-  teststat <- monteCarloSimulation(n = 215, r = 100, family = "mDependentPS", filter = testfilter)
+  teststat <- stepR::monteCarloSimulation(n = 215, r = 100, family = "mDependentPS", filter = testfilter)
   
   expect_error(stepDetection(data = testdata, filter = testfilter, alpha = "s", stat = teststat))
   expect_error(stepDetection(data = testdata, filter = testfilter, alpha = NULL, stat = teststat))
@@ -457,29 +455,29 @@ test_that("argument alpha works and is tested", {
   
   compareq <- getCritVal(n = length(testdata), stat = teststat, filter = testfilter)
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = 0,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = compareq,
-                             filter = testfilter)
-  compare <- stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 0)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = compareq,
+                            filter = testfilter)
+  compare <- stepR::stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 0)
   expect_identical(stepDetection(data = testdata, filter = testfilter, stat = teststat),
                    testIncremental(compare, thresholdIncremental = 8L))
   
   compare <- list(fit = testIncremental(compare, thresholdIncremental = 8L), stepfit = compare,
-                  q = compareq, filter = testfilter, sd = sdrobnorm(testdata, lag = 9L))
+                  q = compareq, filter = testfilter, sd = stepR::sdrobnorm(testdata, lag = 9L))
   expect_identical(stepDetection(data = testdata, filter = testfilter, stat = teststat,
                                  output = "every"), compare)
-
+  
   compareq <- getCritVal(n = length(testdata), stat = teststat, alpha = 0.135, filter = testfilter)
   compare <- stepR::stepFit(y = testdata, x = seq(along = testdata) / testfilter$sr, x0 = 0,
-                             family = "mDependentPS", intervalSystem = "dyaLen", q = compareq,
-                             filter = testfilter)
-  compare <- stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
-                       rightEnd = compare$rightEnd, x0 = 0)
+                            family = "mDependentPS", intervalSystem = "dyaLen", q = compareq,
+                            filter = testfilter)
+  compare <- stepR::stepblock(value = compare$value, leftEnd = c(0, compare$rightEnd[-length(compare$rightEnd)]),
+                              rightEnd = compare$rightEnd, x0 = 0)
   expect_identical(stepDetection(data = testdata, filter = testfilter, stat = teststat, alpha = 0.135),
                    testIncremental(compare, thresholdIncremental = 8L))
   
   compare <- list(fit = testIncremental(compare, thresholdIncremental = 8L), stepfit = compare,
-                  q = compareq, filter = testfilter, sd = sdrobnorm(testdata, lag = 9L))
+                  q = compareq, filter = testfilter, sd = stepR::sdrobnorm(testdata, lag = 9L))
   expect_identical(stepDetection(data = testdata, filter = testfilter, stat = teststat, alpha = 0.135,
                                  output = "every"), compare)
 })
@@ -489,11 +487,11 @@ test_that("argument ... works and is tested", {
   testfilter <- lowpassFilter(type = "bessel", param = list(pole = 4L, cutoff = 0.1), sr = 1, len = 8L,
                               shift = 0.5)
   testdata <- .convolve(testdata, testfilter)
-  teststat <- monteCarloSimulation(n = 215, r = 100, family = "mDependentPS", filter = testfilter)
+  teststat <- stepR::monteCarloSimulation(n = 215, r = 100, family = "mDependentPS", filter = testfilter)
   
   expect_error(stepDetection(data = testdata, filter = testfilter, stat = teststat, family = "gauss"))
-  expect_error(stepDetection(data = testdata, filter = testfilter, stat = teststat, intervalSystem = "all"))
-  expect_error(stepDetection(data = testdata, filter = testfilter, stat = teststat, neuv = "1"))
+  expect_warning(stepDetection(data = testdata, filter = testfilter, stat = teststat, intervalSystem = "all"))
+  expect_warning(stepDetection(data = testdata, filter = testfilter, stat = teststat, neuv = "1"))
   expect_error(stepDetection(data = testdata, filter = testfilter, stat = teststat, n = 215))
   
   expect_error(stepDetection(data = testdata, filter = testfilter, stat = rnorm(100)))
@@ -556,14 +554,14 @@ test_that("argument ... works and is tested", {
   testfile <- tempfile(pattern = "file", tmpdir = tempdir(), fileext = ".RDS")
   testvariable <- "test"
   testStepR <- new.env()
-
+  
   testfilter1 <- lowpassFilter(param = list(pole = 4L, cutoff = 0.1), len = 8)
-  teststat1 <- monteCarloSimulation(n = 215, r = 100, family = "mDependentPS",
-                                    filter = testfilter1, output = "maximum")
+  teststat1 <- stepR::monteCarloSimulation(n = 215, r = 100, family = "mDependentPS",
+                                           filter = testfilter1, output = "maximum")
   expect_identical(stepDetection(data = testdata, filter = testfilter1, r = 100L, output = "every",
-                              options = list(save = list(RDSfile = testfile, variable = testvariable,
-                                                         workspace = c("vector", "vectorIncreased")),
-                                             load = list(), envir = testStepR, dirs = "testStepR")),
+                                 options = list(save = list(RDSfile = testfile, variable = testvariable,
+                                                            workspace = c("vector", "vectorIncreased")),
+                                                load = list(), envir = testStepR, dirs = "testStepR")),
                    stepDetection(data = testdata, stat = teststat1, filter = testfilter1, output = "every",
                                  options = list(save = list())))
   expect_identical(readRDS(testfile), teststat1)
@@ -571,8 +569,8 @@ test_that("argument ... works and is tested", {
   remove(test, envir = testStepR)
   
   testfilter2 <- lowpassFilter(param = list(pole = 4L, cutoff = 0.2), len = 8)
-  teststat2 <- monteCarloSimulation(n = 215, r = 100, family = "mDependentPS",
-                                    filter = testfilter2, output = "maximum")
+  teststat2 <- stepR::monteCarloSimulation(n = 215, r = 100, family = "mDependentPS",
+                                           filter = testfilter2, output = "maximum")
   expect_identical(stepDetection(data = testdata, filter = testfilter2, r = 100L, output = "every",
                                  options = list(envir = testStepR, dirs = "testStepR", 
                                                 save = list(fileSystem = "vector", workspace = "vector"))),
@@ -581,59 +579,59 @@ test_that("argument ... works and is tested", {
   
   expect_identical(stepDetection(data = testdata, filter = testfilter1, r = 200L,
                                  options = list(load = list(RDSfile = testfile), save = list(fileSystem = "vector"),
-                                             envir = testStepR, dirs = "testStepR")),
+                                                envir = testStepR, dirs = "testStepR")),
                    stepDetection(data = testdata, stat = teststat1, filter = testfilter1,
                                  options = list(save = list())))
   unlink(testfile)
   
   testfilter3 <- lowpassFilter(param = list(pole = 4L, cutoff = 0.1), len = 11)
-  teststat3 <- monteCarloSimulation(n = 215, r = 100, family = "mDependentPS",
-                                    filter = testfilter3, output = "maximum")
+  teststat3 <- stepR::monteCarloSimulation(n = 215, r = 100, family = "mDependentPS",
+                                           filter = testfilter3, output = "maximum")
   expect_identical(getCritVal(n = 200L, filter = testfilter3, r = 100L, nq = 215L,
                               options = list(save = list(workspace = "vector", fileSystem = "vectorIncreased"),
                                              envir = testStepR, dirs = "testStepR")),
                    getCritVal(n = 200L, stat = teststat3, filter = testfilter3, options = list(save = list())))
   
   expect_identical(stepDetection(data = testdata, filter = testfilter3, r = 50L, nq = 320L, output = "every",
-                              options = list(save = list(workspace = "vector", fileSystem = "vectorIncreased"),
-                                             envir = testStepR, dirs = "testStepR")),
+                                 options = list(save = list(workspace = "vector", fileSystem = "vectorIncreased"),
+                                                envir = testStepR, dirs = "testStepR")),
                    stepDetection(data = testdata, stat = teststat3, filter = testfilter3, output = "every",
                                  options = list(save = list())))
   
-  teststat4 <- monteCarloSimulation(n = 320, r = 100, family = "mDependentPS", lengths = 2^(0:7),
-                                    filter = testfilter3, output = "maximum")
+  teststat4 <- stepR::monteCarloSimulation(n = 320, r = 100, family = "mDependentPS", lengths = 2^(0:7),
+                                           filter = testfilter3, output = "maximum")
   expect_identical(stepDetection(data = testdata, filter = testfilter3, r = 100L, nq = 320L, output = "every",
-                              options = list(save = list(workspace = "vector", fileSystem = "vectorIncreased"),
-                                             load = list(workspace = "vectorIncreased"),
-                                             envir = testStepR, dirs = "testStepR")),
+                                 options = list(save = list(workspace = "vector", fileSystem = "vectorIncreased"),
+                                                load = list(workspace = "vectorIncreased"),
+                                                envir = testStepR, dirs = "testStepR")),
                    stepDetection(data = testdata, stat = teststat4, filter = testfilter3, output = "every",
                                  options = list(save = list())))
   
   expect_identical(stepDetection(data = testdata, filter = testfilter3, r = 100L, nq = 320L, output = "every",
-                              options = list(simulation = "vector",
-                                             save = list(workspace = "vector", fileSystem = "vectorIncreased"),
-                                             load = list(workspace = "vectorIncreased"),
-                                             envir = testStepR, dirs = "testStepR")),
+                                 options = list(simulation = "vector",
+                                                save = list(workspace = "vector", fileSystem = "vectorIncreased"),
+                                                load = list(workspace = "vectorIncreased"),
+                                                envir = testStepR, dirs = "testStepR")),
                    stepDetection(data = testdata, stat = teststat3, filter = testfilter3, output = "every",
                                  options = list(save = list())))
   
-  teststat5 <- monteCarloSimulation(n = 320, r = 200, family = "mDependentPS", lengths = 2^(0:7),
-                                    filter = testfilter3, output = "maximum")
+  teststat5 <- stepR::monteCarloSimulation(n = 320, r = 200, family = "mDependentPS", lengths = 2^(0:7),
+                                           filter = testfilter3, output = "maximum")
   expect_identical(stepDetection(data = testdata, filter = testfilter3, r = 200L, nq = 320L, output = "every",
-                              options = list(save = list(workspace = "vectorIncreased",
-                                                         fileSystem = "vector"),
-                                             load = list(workspace = "vectorIncreased",
-                                                         fileSystem = "vectorIncreased"),
-                                             envir = testStepR, dirs = "testStepR")),
+                                 options = list(save = list(workspace = "vectorIncreased",
+                                                            fileSystem = "vector"),
+                                                load = list(workspace = "vectorIncreased",
+                                                            fileSystem = "vectorIncreased"),
+                                                envir = testStepR, dirs = "testStepR")),
                    stepDetection(data = testdata, stat = teststat5, filter = testfilter3, output = "every",
                                  options = list(save = list())))
   
   expect_identical(stepDetection(data = testdata, filter = testfilter3, r = 100L, nq = 320L, output = "every",
-                              options = list(save = list(workspace = "vectorIncreased",
-                                                         fileSystem = "vector"),
-                                             load = list(workspace = "vectorIncreased",
-                                                         fileSystem = "vectorIncreased"),
-                                             envir = testStepR, dirs = "testStepR")),
+                                 options = list(save = list(workspace = "vectorIncreased",
+                                                            fileSystem = "vector"),
+                                                load = list(workspace = "vectorIncreased",
+                                                            fileSystem = "vectorIncreased"),
+                                                envir = testStepR, dirs = "testStepR")),
                    stepDetection(data = testdata, stat = teststat5, filter = testfilter3, output = "every",
                                  options = list(save = list())))
   
